==> cxf-services-xkms-common-3.5.9-sources.jar: org/apache/cxf/xkms/model/xkms/CompoundRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CompoundRequestType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CompoundRequestType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&gt;
 *       &lt;choice maxOccurs="unbounded"&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}LocateRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidateRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RegisterRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ReissueRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RecoverRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevokeRequest"/&gt;
 *       &lt;/choice&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CompoundRequestType", propOrder = {
    "locateRequestOrValidateRequestOrRegisterRequest"
})
public class CompoundRequestType
    extends RequestAbstractType
{

    @XmlElements({
        @XmlElement(name = "LocateRequest", type = LocateRequestType.class),
        @XmlElement(name = "ValidateRequest", type = ValidateRequestType.class),
        @XmlElement(name = "RegisterRequest", type = RegisterRequestType.class),
        @XmlElement(name = "ReissueRequest", type = ReissueRequestType.class),
        @XmlElement(name = "RecoverRequest", type = RecoverRequestType.class),
        @XmlElement(name = "RevokeRequest", type = RevokeRequestType.class)
    })
    protected List<RequestAbstractType> locateRequestOrValidateRequestOrRegisterRequest;

    /**
     * Gets the value of the locateRequestOrValidateRequestOrRegisterRequest property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the locateRequestOrValidateRequestOrRegisterRequest property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getLocateRequestOrValidateRequestOrRegisterRequest().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LocateRequestType }
     * {@link RecoverRequestType }
     * {@link RegisterRequestType }
     * {@link ReissueRequestType }
     * {@link RevokeRequestType }
     * {@link ValidateRequestType }
     * 
     * 
     */
    public List<RequestAbstractType> getLocateRequestOrValidateRequestOrRegisterRequest() {
        if (locateRequestOrValidateRequestOrRegisterRequest == null) {
            locateRequestOrValidateRequestOrRegisterRequest = new ArrayList<RequestAbstractType>();
        }
        return this.locateRequestOrValidateRequestOrRegisterRequest;
    }

}

==> cxf-services-xkms-common-4.0.3-sources.jar: org/apache/cxf/xkms/model/xkms/CompoundRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlElements;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CompoundRequestType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CompoundRequestType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&gt;
 *       &lt;choice maxOccurs="unbounded"&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}LocateRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidateRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RegisterRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ReissueRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RecoverRequest"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevokeRequest"/&gt;
 *       &lt;/choice&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CompoundRequestType", propOrder = {
    "locateRequestOrValidateRequestOrRegisterRequest"
})
public class CompoundRequestType
    extends RequestAbstractType
{

    @XmlElements({
        @XmlElement(name = "LocateRequest", type = LocateRequestType.class),
        @XmlElement(name = "ValidateRequest", type = ValidateRequestType.class),
        @XmlElement(name = "RegisterRequest", type = RegisterRequestType.class),
        @XmlElement(name = "ReissueRequest", type = ReissueRequestType.class),
        @XmlElement(name = "RecoverRequest", type = RecoverRequestType.class),
        @XmlElement(name = "RevokeRequest", type = RevokeRequestType.class)
    })
    protected List<RequestAbstractType> locateRequestOrValidateRequestOrRegisterRequest;

    /**
     * Gets the value of the locateRequestOrValidateRequestOrRegisterRequest property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a <CODE>set</CODE> method for the locateRequestOrValidateRequestOrRegisterRequest property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getLocateRequestOrValidateRequestOrRegisterRequest().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LocateRequestType }
     * {@link RecoverRequestType }
     * {@link RegisterRequestType }
     * {@link ReissueRequestType }
     * {@link RevokeRequestType }
     * {@link ValidateRequestType }
     * 
     * 
     */
    public List<RequestAbstractType> getLocateRequestOrValidateRequestOrRegisterRequest() {
        if (locateRequestOrValidateRequestOrRegisterRequest == null) {
            locateRequestOrValidateRequestOrRegisterRequest = new ArrayList<RequestAbstractType>();
        }
        return this.locateRequestOrValidateRequestOrRegisterRequest;
    }

}
